@@ -2,6 +2,7 @@ Mxy <- function(row, data, pop1, pop2, allele.column, ref.pop=NA)
   
 {
   
+  
   # Estimate compare Blouin 1996
   
   # Similarity is given by:
@@ -11,13 +12,15 @@ Mxy <- function(row, data, pop1, pop2, allele.column, ref.pop=NA)
   # 1,1 - 1,1 : 1
   # Rest      : 0
   
-  sum(c(
-    (pop1[data[row,1],(allele.column*2+1)]),
-    (pop1[data[row,1],(allele.column*2+2)])
-  )== 
-    c(
-      (pop2[data[row,2],(allele.column*2+1)]),
-      (pop2[data[row,2],(allele.column*2+2)])
-    ))/2
+  re <- .subset2(data,1)[row]
+  rat <- .subset2(data,2)[row]
+  a <- allele.column*2+1
+  
+  ai <- .subset2(pop1,a)[re]
+  aj <- .subset2(pop1,a+1)[re]
+  bi <- .subset2(pop2,a)[rat]
+  bj <- .subset2(pop2,a+1)[rat]
+  
+  sum(c(ai,aj)==c(bi,bj))/2
   
 }
\ No newline at end of file
