@@ -9,7 +9,7 @@ wang.fin.w <- function(allele.column, ref.pop = NA)
 {
   
 
-p <- as.numeric(as.character(unlist(ref.pop[allele.column])))
+p <- ref.pop
 
 # p=vector of observed gene frequencies i,j,k .. n 
 # m=given by category of P
@@ -28,17 +28,17 @@ p <- as.numeric(as.character(unlist(ref.pop[allele.column])))
 
 u <- 2*a2-a3
 
-b <- (2*a5-a4)/(u)
+b <- (2*a5-a4)/u
 
-c <- (a2-2*a5+a4)/(u)
+c <- (a2-2*a5+a4)/u
 
-d <- (4*(a3-a4))/(u)
+d <- 4*(a3-a4)/u
 
-e <- (2*(a2 - 3*a3 + 2*a4))/(u)
+e <- 2*(a2 - 3*a3 + 2*a4)/u
 
-f <- (4*(a2-a5-2*a3+2*a4))/(u)
+f <- 4*(a2-a5-2*a3+2*a4)/u
 
-g <- (1-7*a2+4*a5+10*a3-8*a4)/(u)
+g <- (1-7*a2+4*a5+10*a3-8*a4)/u
 
 
 return(c(b,c,d,e,f,g,u))
